==> drop-seq_2.3.0+dfsg.orig.tar.xz: Drop-seq-2.3.0/src/java/org/broadinstitute/dropseqrna/utils/readiterators/SamHeaderAndIterator.java <==
/*
 * MIT License
 *
 * Copyright 2017 Broad Institute
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.broadinstitute.dropseqrna.utils.readiterators;

import java.io.File;

import htsjdk.samtools.SAMFileHeader;
import htsjdk.samtools.SAMRecord;
import htsjdk.samtools.SamReader;
import htsjdk.samtools.SamReaderFactory;
import htsjdk.samtools.util.CloseableIterator;

public class SamHeaderAndIterator {
    public final SAMFileHeader header;
    public final CloseableIterator<SAMRecord> iterator;

    public SamHeaderAndIterator(SAMFileHeader header, CloseableIterator<SAMRecord> iterator) {
        this.header = header;
        this.iterator = iterator;
    }
    
    public SamHeaderAndIterator (SamReader reader) {
    	this(reader.getFileHeader(), reader.iterator());
    }
    
    public SamHeaderAndIterator (File bamFile) {
    	this(SamReaderFactory.makeDefault().open(bamFile));  	    	
    }
}

==> drop-seq_2.5.4+dfsg.orig.tar.xz: Drop-seq-2.5.4/src/java/org/broadinstitute/dropseqrna/utils/readiterators/SamHeaderAndIterator.java <==
/*
 * MIT License
 *
 * Copyright 2017 Broad Institute
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package org.broadinstitute.dropseqrna.utils.readiterators;

import java.io.File;

import htsjdk.samtools.SAMFileHeader;
import htsjdk.samtools.SAMRecord;
import htsjdk.samtools.SamReader;
import htsjdk.samtools.SamReaderFactory;
import htsjdk.samtools.SamReaderFactory.Option;
import htsjdk.samtools.util.CloseableIterator;

public class SamHeaderAndIterator {
    public final SAMFileHeader header;
    public final CloseableIterator<SAMRecord> iterator;

    public SamHeaderAndIterator(SAMFileHeader header, CloseableIterator<SAMRecord> iterator) {
        this.header = header;
        this.iterator = iterator;
    }
    
    public SamHeaderAndIterator (SamReader reader) {
    	this(reader.getFileHeader(), reader.iterator());
    }
    
    public SamHeaderAndIterator (File bamFile) {
    	this(SamReaderFactory.makeDefault().open(bamFile));  	    	
    }
    
    public SamHeaderAndIterator (File bamFile, Option... options) {    	
    	this(SamReaderFactory.makeDefault().enable(options).open(bamFile));    	    	
    }
        
}
